@@ -6,7 +6,7 @@ from .client import RaggerClient
 # Import constants for convenience
 from .constants import APIEndpoints
 from .constants import ErrorCodes
-from .constants import FileConstants
+from .constants import DocumentConstants
 
 # Import exceptions
 from .exceptions import RaggerAPIError
@@ -17,5 +17,5 @@ __all__ = [
     "RaggerAPIError",
     "APIEndpoints",
     "ErrorCodes",
-    "FileConstants",
+    "DocumentConstants",
 ]
